==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeAttachmentSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1beta1VolumeAttachmentSpecFluent<A extends V1beta1VolumeAttachmentSpecFluent<A>> extends Fluent<A>{


    public String getAttacher();
    public A withAttacher(String attacher);
    public Boolean hasAttacher();
    public String getNodeName();
    public A withNodeName(String nodeName);
    public Boolean hasNodeName();
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1VolumeAttachmentSource getSource();
    public V1beta1VolumeAttachmentSource buildSource();
    public A withSource(V1beta1VolumeAttachmentSource source);
    public Boolean hasSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> withNewSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> withNewSourceLike(V1beta1VolumeAttachmentSource item);
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> editSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSourceLike(V1beta1VolumeAttachmentSource item);

    public interface SourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1VolumeAttachmentSourceFluent<V1beta1VolumeAttachmentSpecFluent.SourceNested<N>>{

        
    public N and();    public N endSource();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeAttachmentSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1beta1VolumeAttachmentSpecFluent<A extends V1beta1VolumeAttachmentSpecFluent<A>> extends Fluent<A>{


    public String getAttacher();
    public A withAttacher(String attacher);
    public Boolean hasAttacher();
    public A withNewAttacher(String arg1);
    public A withNewAttacher(StringBuilder arg1);
    public A withNewAttacher(StringBuffer arg1);
    public String getNodeName();
    public A withNodeName(String nodeName);
    public Boolean hasNodeName();
    public A withNewNodeName(String arg1);
    public A withNewNodeName(StringBuilder arg1);
    public A withNewNodeName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1VolumeAttachmentSource getSource();
    public V1beta1VolumeAttachmentSource buildSource();
    public A withSource(V1beta1VolumeAttachmentSource source);
    public Boolean hasSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> withNewSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> withNewSourceLike(V1beta1VolumeAttachmentSource item);
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> editSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSource();
    public V1beta1VolumeAttachmentSpecFluent.SourceNested<A> editOrNewSourceLike(V1beta1VolumeAttachmentSource item);

    public interface SourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1VolumeAttachmentSourceFluent<V1beta1VolumeAttachmentSpecFluent.SourceNested<N>>{

        
    public N and();    public N endSource();
}


}
